Documentation
¶
Index ¶
- Variables
- type IdemixMSPConfig
- func (*IdemixMSPConfig) Descriptor() ([]byte, []int)deprecated
- func (x *IdemixMSPConfig) GetCurveId() string
- func (x *IdemixMSPConfig) GetEpoch() int64
- func (x *IdemixMSPConfig) GetIpk() []byte
- func (x *IdemixMSPConfig) GetName() string
- func (x *IdemixMSPConfig) GetRevocationPk() []byte
- func (x *IdemixMSPConfig) GetSchema() string
- func (x *IdemixMSPConfig) GetSigner() *IdemixMSPSignerConfig
- func (*IdemixMSPConfig) ProtoMessage()
- func (x *IdemixMSPConfig) ProtoReflect() protoreflect.Message
- func (x *IdemixMSPConfig) Reset()
- func (x *IdemixMSPConfig) String() string
- type IdemixMSPSignerConfig
- func (*IdemixMSPSignerConfig) Descriptor() ([]byte, []int)deprecated
- func (x *IdemixMSPSignerConfig) GetCred() []byte
- func (x *IdemixMSPSignerConfig) GetCredentialRevocationInformation() []byte
- func (x *IdemixMSPSignerConfig) GetCurveId() string
- func (x *IdemixMSPSignerConfig) GetEnrollmentId() string
- func (x *IdemixMSPSignerConfig) GetOrganizationalUnitIdentifier() string
- func (x *IdemixMSPSignerConfig) GetRevocationHandle() string
- func (x *IdemixMSPSignerConfig) GetRole() int32
- func (x *IdemixMSPSignerConfig) GetSchema() string
- func (x *IdemixMSPSignerConfig) GetSk() []byte
- func (*IdemixMSPSignerConfig) ProtoMessage()
- func (x *IdemixMSPSignerConfig) ProtoReflect() protoreflect.Message
- func (x *IdemixMSPSignerConfig) Reset()
- func (x *IdemixMSPSignerConfig) String() string
- type SerializedIdemixIdentity
- func (*SerializedIdemixIdentity) Descriptor() ([]byte, []int)deprecated
- func (x *SerializedIdemixIdentity) GetNymX() []byte
- func (x *SerializedIdemixIdentity) GetNymY() []byte
- func (x *SerializedIdemixIdentity) GetOu() []byte
- func (x *SerializedIdemixIdentity) GetProof() []byte
- func (x *SerializedIdemixIdentity) GetRole() []byte
- func (x *SerializedIdemixIdentity) GetSchema() string
- func (*SerializedIdemixIdentity) ProtoMessage()
- func (x *SerializedIdemixIdentity) ProtoReflect() protoreflect.Message
- func (x *SerializedIdemixIdentity) Reset()
- func (x *SerializedIdemixIdentity) String() string
Constants ¶
This section is empty.
Variables ¶
var File_msp_config_identities_proto protoreflect.FileDescriptor
var File_msp_config_msp_config_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type IdemixMSPConfig ¶
type IdemixMSPConfig struct {
// Name holds the identifier of the MSP
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// ipk represents the (serialized) issuer public key
Ipk []byte `protobuf:"bytes,2,opt,name=ipk,proto3" json:"ipk,omitempty"`
// signer may contain crypto material to configure a default signer
Signer *IdemixMSPSignerConfig `protobuf:"bytes,3,opt,name=signer,proto3" json:"signer,omitempty"`
// revocation_pk is the public key used for revocation of credentials
RevocationPk []byte `protobuf:"bytes,4,opt,name=revocation_pk,json=revocationPk,proto3" json:"revocation_pk,omitempty"`
// epoch represents the current epoch (time interval) used for revocation
Epoch int64 `protobuf:"varint,5,opt,name=epoch,proto3" json:"epoch,omitempty"`
// curve_id indicates which Elliptic Curve should be used
CurveId string `protobuf:"bytes,6,opt,name=curve_id,json=curveId,proto3" json:"curve_id,omitempty"`
// schema contains the version of the schema used by this credential
Schema string `protobuf:"bytes,7,opt,name=schema,proto3" json:"schema,omitempty"`
// contains filtered or unexported fields
}
func (*IdemixMSPConfig) Descriptor
deprecated
func (*IdemixMSPConfig) Descriptor() ([]byte, []int)
Deprecated: Use IdemixMSPConfig.ProtoReflect.Descriptor instead.
func (*IdemixMSPConfig) GetCurveId ¶
func (x *IdemixMSPConfig) GetCurveId() string
func (*IdemixMSPConfig) GetEpoch ¶
func (x *IdemixMSPConfig) GetEpoch() int64
func (*IdemixMSPConfig) GetIpk ¶
func (x *IdemixMSPConfig) GetIpk() []byte
func (*IdemixMSPConfig) GetName ¶
func (x *IdemixMSPConfig) GetName() string
func (*IdemixMSPConfig) GetRevocationPk ¶
func (x *IdemixMSPConfig) GetRevocationPk() []byte
func (*IdemixMSPConfig) GetSchema ¶
func (x *IdemixMSPConfig) GetSchema() string
func (*IdemixMSPConfig) GetSigner ¶
func (x *IdemixMSPConfig) GetSigner() *IdemixMSPSignerConfig
func (*IdemixMSPConfig) ProtoMessage ¶
func (*IdemixMSPConfig) ProtoMessage()
func (*IdemixMSPConfig) ProtoReflect ¶
func (x *IdemixMSPConfig) ProtoReflect() protoreflect.Message
func (*IdemixMSPConfig) Reset ¶
func (x *IdemixMSPConfig) Reset()
func (*IdemixMSPConfig) String ¶
func (x *IdemixMSPConfig) String() string
type IdemixMSPSignerConfig ¶
type IdemixMSPSignerConfig struct {
// cred represents the serialized idemix credential of the default signer
Cred []byte `protobuf:"bytes,1,opt,name=cred,proto3" json:"cred,omitempty"`
// sk is the secret key of the default signer, corresponding to credential Cred
Sk []byte `protobuf:"bytes,2,opt,name=sk,proto3" json:"sk,omitempty"`
// organizational_unit_identifier defines the organizational unit the default signer is in
OrganizationalUnitIdentifier string `` /* 147-byte string literal not displayed */
// role defines whether the default signer is admin, peer, member or client
Role int32 `protobuf:"varint,4,opt,name=role,proto3" json:"role,omitempty"`
// enrollment_id contains the enrollment id of this signer
EnrollmentId string `protobuf:"bytes,5,opt,name=enrollment_id,json=enrollmentId,proto3" json:"enrollment_id,omitempty"`
// credential_revocation_information contains a serialized CredentialRevocationInformation
CredentialRevocationInformation []byte `` /* 156-byte string literal not displayed */
// RevocationHandle is the handle used to single out this credential and determine its revocation status
RevocationHandle string `protobuf:"bytes,7,opt,name=revocation_handle,json=revocationHandle,proto3" json:"revocation_handle,omitempty"`
// curve_id indicates which Elliptic Curve should be used
CurveId string `protobuf:"bytes,8,opt,name=curve_id,json=curveId,proto3" json:"curve_id,omitempty"`
// schema contains the version of the schema used by this credential
Schema string `protobuf:"bytes,9,opt,name=schema,proto3" json:"schema,omitempty"`
// contains filtered or unexported fields
}
IdemixMSPSIgnerConfig contains the crypto material to set up an idemix signing identity
func (*IdemixMSPSignerConfig) Descriptor
deprecated
func (*IdemixMSPSignerConfig) Descriptor() ([]byte, []int)
Deprecated: Use IdemixMSPSignerConfig.ProtoReflect.Descriptor instead.
func (*IdemixMSPSignerConfig) GetCred ¶
func (x *IdemixMSPSignerConfig) GetCred() []byte
func (*IdemixMSPSignerConfig) GetCredentialRevocationInformation ¶
func (x *IdemixMSPSignerConfig) GetCredentialRevocationInformation() []byte
func (*IdemixMSPSignerConfig) GetCurveId ¶
func (x *IdemixMSPSignerConfig) GetCurveId() string
func (*IdemixMSPSignerConfig) GetEnrollmentId ¶
func (x *IdemixMSPSignerConfig) GetEnrollmentId() string
func (*IdemixMSPSignerConfig) GetOrganizationalUnitIdentifier ¶
func (x *IdemixMSPSignerConfig) GetOrganizationalUnitIdentifier() string
func (*IdemixMSPSignerConfig) GetRevocationHandle ¶
func (x *IdemixMSPSignerConfig) GetRevocationHandle() string
func (*IdemixMSPSignerConfig) GetRole ¶
func (x *IdemixMSPSignerConfig) GetRole() int32
func (*IdemixMSPSignerConfig) GetSchema ¶
func (x *IdemixMSPSignerConfig) GetSchema() string
func (*IdemixMSPSignerConfig) GetSk ¶
func (x *IdemixMSPSignerConfig) GetSk() []byte
func (*IdemixMSPSignerConfig) ProtoMessage ¶
func (*IdemixMSPSignerConfig) ProtoMessage()
func (*IdemixMSPSignerConfig) ProtoReflect ¶
func (x *IdemixMSPSignerConfig) ProtoReflect() protoreflect.Message
func (*IdemixMSPSignerConfig) Reset ¶
func (x *IdemixMSPSignerConfig) Reset()
func (*IdemixMSPSignerConfig) String ¶
func (x *IdemixMSPSignerConfig) String() string
type SerializedIdemixIdentity ¶
type SerializedIdemixIdentity struct {
// nym_x is the X-component of the pseudonym elliptic curve point.
// It is a []byte representation of an amcl.BIG
// The pseudonym can be seen as a public key of the identity, it is used to verify signatures.
NymX []byte `protobuf:"bytes,1,opt,name=nym_x,json=nymX,proto3" json:"nym_x,omitempty"`
// nym_y is the Y-component of the pseudonym elliptic curve point.
// It is a []byte representation of an amcl.BIG
// The pseudonym can be seen as a public key of the identity, it is used to verify signatures.
NymY []byte `protobuf:"bytes,2,opt,name=nym_y,json=nymY,proto3" json:"nym_y,omitempty"`
// ou contains the organizational unit of the idemix identity
Ou []byte `protobuf:"bytes,3,opt,name=ou,proto3" json:"ou,omitempty"`
// role contains the role of this identity (e.g., ADMIN or MEMBER)
Role []byte `protobuf:"bytes,4,opt,name=role,proto3" json:"role,omitempty"`
// proof contains the cryptographic evidence that this identity is valid
Proof []byte `protobuf:"bytes,5,opt,name=proof,proto3" json:"proof,omitempty"`
// schema contains the version of the schema used by this credential
Schema string `protobuf:"bytes,6,opt,name=schema,proto3" json:"schema,omitempty"`
// contains filtered or unexported fields
}
This struct represents an Idemix Identity to be used to serialize it and deserialize it. The IdemixMSP will first serialize an idemix identity to bytes using this proto, and then uses these bytes as id_bytes in SerializedIdentity
func (*SerializedIdemixIdentity) Descriptor
deprecated
func (*SerializedIdemixIdentity) Descriptor() ([]byte, []int)
Deprecated: Use SerializedIdemixIdentity.ProtoReflect.Descriptor instead.
func (*SerializedIdemixIdentity) GetNymX ¶
func (x *SerializedIdemixIdentity) GetNymX() []byte
func (*SerializedIdemixIdentity) GetNymY ¶
func (x *SerializedIdemixIdentity) GetNymY() []byte
func (*SerializedIdemixIdentity) GetOu ¶
func (x *SerializedIdemixIdentity) GetOu() []byte
func (*SerializedIdemixIdentity) GetProof ¶
func (x *SerializedIdemixIdentity) GetProof() []byte
func (*SerializedIdemixIdentity) GetRole ¶
func (x *SerializedIdemixIdentity) GetRole() []byte
func (*SerializedIdemixIdentity) GetSchema ¶
func (x *SerializedIdemixIdentity) GetSchema() string
func (*SerializedIdemixIdentity) ProtoMessage ¶
func (*SerializedIdemixIdentity) ProtoMessage()
func (*SerializedIdemixIdentity) ProtoReflect ¶
func (x *SerializedIdemixIdentity) ProtoReflect() protoreflect.Message
func (*SerializedIdemixIdentity) Reset ¶
func (x *SerializedIdemixIdentity) Reset()
func (*SerializedIdemixIdentity) String ¶
func (x *SerializedIdemixIdentity) String() string
Click to show internal directories.
Click to hide internal directories.